<?php
session_start();
require_once '../config.php';

// Cek apakah admin sudah login
if (!isset($_SESSION['admin_logged_in']) || $_SESSION['admin_logged_in'] !== true) {
    header("Location: admin_login.php");
    exit;
}

// Proses verifikasi pembayaran
if (isset($_GET['verify']) && isset($_GET['order_id'])) {
    $order_id = (int)$_GET['order_id'];
    
    // Update status pesanan menjadi "success"
    $stmt = $pdo->prepare("UPDATE orders SET status = 'success' WHERE id = ?");
    $stmt->execute([$order_id]);
    
    // Update tabel payments (opsional: catat siapa yang memverifikasi)
    $stmt = $pdo->prepare("UPDATE payments SET verified_at = NOW(), verified_by = 'admin' WHERE order_id = ?");
    $stmt->execute([$order_id]);
    
    header("Location: admin_dashboard.php");
    exit;
}

// Ambil daftar pesanan dengan status "waiting"
$stmt = $pdo->query("SELECT o.*, p.proof_url FROM orders o LEFT JOIN payments p ON o.id = p.order_id WHERE o.status = 'waiting'");
$orders = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="id">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Dashboard Admin - Sefsar Ticket</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            margin: 0;
            padding: 0;
            background-color: #f4f4f4;
        }
        .container {
            max-width: 1000px;
            margin: 20px auto;
            padding: 20px;
            background-color: white;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }
        h2 {
            margin-top: 0;
        }
        table {
            width: 100%;
            border-collapse: collapse;
            margin-top: 20px;
        }
        th, td {
            padding: 10px;
            border: 1px solid #ccc;
            text-align: left;
        }
        th {
            background-color: #28a745;
            color: white;
        }
        a {
            color: #28a745;
            text-decoration: none;
        }
        a:hover {
            text-decoration: underline;
        }
        .verify-btn {
            padding: 5px 10px;
            background-color: #28a745;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }
        .verify-btn:hover {
            background-color: #218838;
        }
        .logout {
            display: block;
            margin-top: 20px;
            color: red;
        }
    </style>
</head>
<body>
    <div class="container">
        <h2>Dashboard Admin</h2>
        <p>Selamat datang, Admin! Berikut adalah daftar pesanan yang menunggu verifikasi:</p>

        <?php if (empty($orders)): ?>
            <p>Tidak ada pesanan yang menunggu verifikasi.</p>
        <?php else: ?>
            <table>
                <thead>
                    <tr>
                        <th>Nomor Transaksi</th>
                        <th>Nama</th>
                        <th>Email</th>
                        <th>Nominal</th>
                        <th>Bukti Transfer</th>
                        <th>Aksi</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($orders as $order): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($order['transaction_id']); ?></td>
                            <td><?php echo htmlspecialchars($order['name']); ?></td>
                            <td><?php echo htmlspecialchars($order['email']); ?></td>
                            <td>Rp <?php echo number_format($order['amount'], 2); ?></td>
                            <td>
                                <?php if ($order['proof_url']): ?>
                                    <a href="<?php echo $base_url . '/' . htmlspecialchars($order['proof_url']); ?>" target="_blank">Lihat Bukti</a>
                                <?php else: ?>
                                    Belum diunggah
                                <?php endif; ?>
                            </td>
                            <td>
                                <a href="?verify=1&order_id=<?php echo $order['id']; ?>" class="verify-btn">Verifikasi</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php endif; ?>

        <a href="admin_logout.php" class="logout">Logout</a>
    </div>
</body>
</html>