<?php
session_start();
require_once 'config.php'; // Memuat konfigurasi database

// Memuat file PHPMailer secara manual
require_once 'PHPMailer/src/Exception.php';
require_once 'PHPMailer/src/PHPMailer.php';
require_once 'PHPMailer/src/SMTP.php';

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

// Ambil daftar event aktif dari tabel events
$stmt = $pdo->query("SELECT * FROM events WHERE status = 'active'");
$events = $stmt->fetchAll();

// Ambil daftar rekening aktif dari tabel bank_accounts
$stmt = $pdo->query("SELECT * FROM bank_accounts WHERE is_active = 'yes'");
$bank_accounts = $stmt->fetchAll();

// Proses form jika disubmit
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = trim($_POST['name']);
    $email = trim($_POST['email']);
    $phone = trim($_POST['phone']);
    $event_id = (int)$_POST['event_id'];

    // Validasi input
    if (empty($name) || empty($email) || empty($phone) || empty($event_id)) {
        $error = "Semua kolom wajib diisi.";
    } elseif (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $error = "Format email tidak valid.";
    } else {
        // Ambil harga event
        $stmt = $pdo->prepare("SELECT price FROM events WHERE id = ? AND status = 'active'");
        $stmt->execute([$event_id]);
        $event = $stmt->fetch();

        if (!$event) {
            $error = "Event tidak ditemukan.";
        } else {
            // Generate kode unik (antara 100-999)
            $unique_code = rand(100, 999);
            $amount = $event['price'] + $unique_code;

            // Generate transaction_id menggunakan prefix dari tabel settings
            $stmt = $pdo->query("SELECT setting_value FROM settings WHERE setting_key = 'transaction_prefix'");
            $prefix = $stmt->fetchColumn() ?: 'TKT';
            $random_num = rand(1000000000, 9999999999);
            $transaction_id = $prefix . $random_num;

            // Simpan ke tabel orders
            $stmt = $pdo->prepare("
                INSERT INTO orders (transaction_id, name, email, phone, amount, unique_code, status, created_at)
                VALUES (?, ?, ?, ?, ?, ?, 'pending', NOW())
            ");
            $stmt->execute([$transaction_id, $name, $email, $phone, $amount, $unique_code]);

            $order_id = $pdo->lastInsertId();

            // Format bank account details for email
            $bank_details = "";
            foreach ($bank_accounts as $account) {
                $bank_details .= "Bank: {$account['bank_name']}\nNo. Rekening: {$account['account_number']}\nAtas Nama: {$account['account_holder']}\n\n";
            }

            // Kirim email konfirmasi menggunakan PHPMailer
            $mail = new PHPMailer(true);
            $email_sent = false; // Variabel untuk melacak keberhasilan pengiriman email

            try {
                // Aktifkan debugging SMTP dan simpan ke file
                $mail->SMTPDebug = 3; // Tingkatkan level debug untuk detail lebih banyak
                $mail->Debugoutput = function($str, $level) {
                    file_put_contents('logs/smtp_debug.log', date('Y-m-d H:i:s') . " $str\n", FILE_APPEND);
                };

                // Pengaturan server SMTP untuk sefsartech.my.id
                $mail->isSMTP();
                $mail->Host = 'mail.sefsartech.my.id';
                $mail->SMTPAuth = true;
                $mail->Username = 'info@sefsartech.my.id';
                $mail->Password = 'T4hubulat';
                $mail->SMTPSecure = PHPMailer::ENCRYPTION_SMTPS; // Gunakan SSL
                $mail->Port = 465;

                // Nonaktifkan verifikasi sertifikat SSL (sementara untuk debugging)
                $mail->SMTPOptions = array(
                    'ssl' => array(
                        'verify_peer' => false,
                        'verify_peer_name' => false,
                        'allow_self_signed' => true
                    )
                );

                // Pengaturan email
                $mail->setFrom('info@sefsartech.my.id', 'Sefsar Ticket');
                $mail->addAddress($email);
                $mail->addReplyTo('info@sefsartech.my.id', 'Sefsar Ticket');
                $mail->addBCC('info@sefsartech.my.id');

                // Konten email
                $mail->isHTML(true); // Ubah ke HTML untuk format yang lebih baik
                $mail->CharSet = 'UTF-8';
                $mail->Subject = "Konfirmasi Pemesanan Tiket #$transaction_id";
                $mail->Body = "
                    <h2>Terima kasih atas pemesanan Anda!</h2>
                    <h3>Detail Pemesanan:</h3>
                    <p><strong>Nama:</strong> $name</p>
                    <p><strong>Email:</strong> $email</p>
                    <p><strong>Nomor HP:</strong> $phone</p>
                    <p><strong>Nominal Transfer:</strong> Rp " . number_format($amount, 2) . "</p>
                    <p><strong>Kode Unik:</strong> $unique_code</p>
                    <p><strong>Nomor Transaksi:</strong> $transaction_id</p>
                    <h3>Silakan transfer ke salah satu rekening berikut:</h3>
                    <p>" . nl2br($bank_details) . "</p>
                    <p>Lihat detail pesanan dan upload bukti transfer di: <a href='$base_url/order_confirmation.php?transaction_id=$transaction_id'>$base_url/order_confirmation.php?transaction_id=$transaction_id</a></p>
                ";
                $mail->AltBody = "
                    Terima kasih atas pemesanan Anda!\n
                    Detail Pemesanan:\n
                    Nama: $name\n
                    Email: $email\n
                    Nomor HP: $phone\n
                    Nominal Transfer: Rp " . number_format($amount, 2) . "\n
                    Kode Unik: $unique_code\n
                    Nomor Transaksi: $transaction_id\n\n
                    Silakan transfer ke salah satu rekening berikut:\n
                    $bank_details
                    Lihat detail pesanan dan upload bukti transfer di: $base_url/order_confirmation.php?transaction_id=$transaction_id
                ";

                // Tambahan header untuk meningkatkan keandalan pengiriman
                $mail->addCustomHeader('X-Mailer', 'PHP/' . phpversion());
                $mail->addCustomHeader('X-Priority', '3');
                $mail->addCustomHeader('Organization', 'Sefsar Ticket');

                // Kirim email
                if ($mail->send()) {
                    $email_sent = true; // Tandai bahwa email berhasil dikirim
                    $success = "Pemesanan berhasil dan email konfirmasi telah dikirim.";
                } else {
                    throw new Exception("Gagal mengirim email konfirmasi.");
                }
            } catch (Exception $e) {
                // Simpan error ke log
                $error_message = "Email tidak terkirim. Error: {$mail->ErrorInfo}";
                error_log($error_message, 3, 'logs/email_error.log');
                $error = $error_message; // Tampilkan error di halaman
            }

            // Redirect hanya jika email berhasil dikirim
            if ($email_sent) {
                header("Location: order_confirmation.php?transaction_id=$transaction_id");
                exit;
            } else {
                // Jika gagal, pesan error akan ditampilkan di halaman (via variabel $error)
                $error = isset($error) ? $error : "Pemesanan berhasil, tetapi gagal mengirim email konfirmasi.";
            }
        }
    }
}
?>

<!DOCTYPE html>
<html lang="id">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Sefsar Ticket - Pesan Tiket Event Anda</title>
    <link href="https://fonts.googleapis.com/css2?family=Poppins:wght@400;600&display=swap" rel="stylesheet">
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }
        body {
            font-family: 'Poppins', sans-serif;
            background: linear-gradient(135deg, #f5f7fa 0%, #c3cfe2 100%);
            color: #333;
        }
        header {
            background: #28a745;
            color: white;
            text-align: center;
            padding: 2rem 1rem;
        }
        header h1 {
            font-size: 2.5rem;
            margin-bottom: 0.5rem;
        }
        header p {
            font-size: 1.2rem;
        }
        .container {
            max-width: 700px;
            margin: 2rem auto;
            background: white;
            padding: 2rem;
            border-radius: 12px;
            box-shadow: 0 4px 20px rgba(0, 0, 0, 0.1);
        }
        h2 {
            text-align: center;
            color: #28a745;
            margin-bottom: 1.5rem;
        }
        .form-group {
            margin-bottom: 1.5rem;
        }
        label {
            display: block;
            font-weight: 600;
            margin-bottom: 0.5rem;
            color: #444;
        }
        input, select {
            width: 100%;
            padding: 0.75rem;
            border: 1px solid #ddd;
            border-radius: 8px;
            font-size: 1rem;
            transition: border-color 0.3s;
        }
        input:focus, select:focus {
            outline: none;
            border-color: #28a745;
        }
        .error {
            color: #dc3545;
            font-size: 0.9rem;
            margin-bottom: 1rem;
            text-align: center;
        }
        .success {
            color: #28a745;
            font-size: 0.9rem;
            margin-bottom: 1rem;
            text-align: center;
        }
        button {
            display: block;
            width: 100%;
            padding: 1rem;
            background: #28a745;
            color: white;
            border: none;
            border-radius: 8px;
            font-size: 1.1rem;
            cursor: pointer;
            transition: background 0.3s;
        }
        button:hover {
            background: #218838;
        }
        footer {
            text-align: center;
            padding: 1rem;
            background: #28a745;
            color: white;
            position: relative;
            margin-top: 2rem;
        }
        @media (max-width: 600px) {
            header h1 {
                font-size: 1.8rem;
            }
            header p {
                font-size: 1rem;
            }
            .container {
                margin: 1rem;
                padding: 1.5rem;
            }
            button {
                font-size: 1rem;
            }
        }
    </style>
</head>
<body>
    <header>
        <h2>Sefsar Ticket</h2>
        <p>Pesan Tiket Event Favorit Anda dengan Mudah!</p>
    </header>

    <div class="container">
        <h2>Pesan Tiket Event</h2>

        <?php if (isset($error)): ?>
            <p class="error"><?php echo htmlspecialchars($error); ?></p>
        <?php endif; ?>

        <?php if (isset($success)): ?>
            <p class="success"><?php echo htmlspecialchars($success); ?></p>
        <?php endif; ?>

        <form method="POST" action="">
            <div class="form-group">
                <label for="name">Nama Lengkap</label>
                <input type="text" id="name" name="name" value="<?php echo isset($_POST['name']) ? htmlspecialchars($_POST['name']) : ''; ?>" required>
            </div>

            <div class="form-group">
                <label for="email">Email</label>
                <input type="email" id="email" name="email" value="<?php echo isset($_POST['email']) ? htmlspecialchars($_POST['email']) : ''; ?>" required>
            </div>

            <div class="form-group">
                <label for="phone">Nomor HP</label>
                <input type="text" id="phone" name="phone" value="<?php echo isset($_POST['phone']) ? htmlspecialchars($_POST['phone']) : ''; ?>" required>
            </div>

            <div class="form-group">
                <label for="event_id">Pilih Event</label>
                <select id="event_id" name="event_id" required>
                    <option value="">-- Pilih Event --</option>
                    <?php foreach ($events as $event): ?>
                        <option value="<?php echo $event['id']; ?>">
                            <?php echo htmlspecialchars($event['name']) . ' - Rp ' . number_format($event['price'], 2); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <button type="submit">Pesan Sekarang</button>
        </form>
    </div>

    <footer>
        <p>© 2025 Sefsar Ticket. All Rights Reserved.</p>
    </footer>
</body>
</html>